@@ -5,8 +5,8 @@ from django.conf import settings
 
 
 def get_forest_setting(setting, default=None):
-    env_setting = os.getenv(setting, default)
-    forest_setting = getattr(settings, 'FOREST', {}).get(setting, env_setting)
+    django_settings = getattr(settings, 'FOREST', {}).get(setting, default)
+    forest_setting = os.getenv(setting, django_settings)
     if isinstance(default, bool) and isinstance(forest_setting, str):
         try:
             forest_setting = strtobool(forest_setting)
